@@ -36,9 +36,10 @@ Most users will want to look at TestWithFixtures and Fixture, to start with.
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 3, 10, 'final', 0)
+__version__ = (0, 3, 11, 'final', 0)
 
 __all__ = [
+    'ByteStream',
     'DetailStream',
     'EnvironmentVariable',
     'EnvironmentVariableFixture',
@@ -47,6 +48,7 @@ __all__ = [
     'Fixture',
     'FunctionFixture',
     'LoggerFixture',
+    'LogHandler',
     'MethodFixture',
     'MonkeyPatch',
     'NestedTempfile',
@@ -54,6 +56,7 @@ __all__ = [
     'PopenFixture',
     'PythonPackage',
     'PythonPathEntry',
+    'StringStream',
     'TempDir',
     'TempHomeDir',
     'TestWithFixtures',
@@ -68,18 +71,21 @@ from fixtures.fixture import (
     MethodFixture,
     )
 from fixtures._fixtures import (
+    ByteStream,
     DetailStream,
     EnvironmentVariable,
     EnvironmentVariableFixture,
     FakeLogger,
     FakePopen,
     LoggerFixture,
+    LogHandler,
     MonkeyPatch,
     NestedTempfile,
     PackagePathEntry,
     PopenFixture,
     PythonPackage,
     PythonPathEntry,
+    StringStream,
     TempDir,
     TempHomeDir,
     Timeout,
